@@ -95,7 +95,7 @@ def fromRepo(args):
         except IOError: pass
     if args.tarfile and not args.list:
         # tar output
-        newesthash=tarOutput(tar,args,repo,oldhash,statusfile,tar)
+        newesthash=tarOutput(args,repo,oldhash,statusfile,tar)
     else:
         # filename output
         newesthash=fileOutput(args,repo,oldhash,statusfile)
